package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.RmsPort;
import com.steerinfo.dil.service.impl.RmsPortServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author luobang
 * @create 2021-11-15 15:13
 */
@RestController
@RequestMapping("/${api.version}/rmsPort")
public class RmsPortController extends BaseRESTfulController {

    @Autowired
    RmsPortServiceImpl rmsPortService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    ESFeign esFeign;

    /**
     * 新增港口
     * @param rmsPort
     * @return
     */
    @PostMapping("/insertPort")
    public RESTfulResult insertPort(@RequestBody(required = true)RmsPort rmsPort){
       Integer integer = rmsPortService.insertPort(rmsPort);
       if (
               integer!=1
       ){
           return failed();
       }
        else{
           return success();
       }

    }

    /**
     * 修改港口
     * @param rmsPort
     * @return
     */
    @PostMapping("/editPort")
    public RESTfulResult editPort(@RequestBody(required = true)RmsPort rmsPort){

        Integer integer = rmsPortService.updatePort(rmsPort);
        if (
                integer!=1
        ){
            return failed();
        }
        else{
            return success();
        }

    }


    /**
     * 删除港口
     * @param portId
     * @return
     */
    @PostMapping("/deletePort/{portId}")
    public RESTfulResult deletePort(@PathVariable("portId") BigDecimal portId){

        Integer integer = rmsPortService.deletePort(portId);
        if (
                integer!=1
        ){
            return failed();
        }
        else{
            return success();
        }

    }


    @ApiOperation(value="展示港口信息", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "196", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getPort")
    public RESTfulResult getPort(@RequestBody(required = false) Map<String,Object> mapVal,
                                         Integer pageNum,
                                         Integer pageSize,
                                         Integer apiId,
                                         String con){
        if (con != null) {
            if(!"undefined".equals(con)){
                String index = "get_rms_port";
                return success(esFeign.getConResult(mapVal,index,apiId,pageNum,pageSize,con));
            }
        }
        List<Map<String,Object>>portList = null;
        if(mapVal.size() ==0 ){
            //将查询结果存入索引中
            portList = rmsPortService.getPort(mapVal);
            Map<String,Object>portMap = new HashMap<>();
            //添加索引
            portMap.put("index","get_rms_port");
            //添加ID
            portMap.put("indexId","portId");
            portList.add(portMap);
            //新建索引
            esFeign.insertIndex(portList);
            //删除
            portList.remove(portList.size()-1);
        }
        if(portList == null){
            portList = rmsPortService.getPort(mapVal);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsPortService.getPort(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, portList, columnList);
        return success(data);
    }

    /**
     * 港口类型ID
     * @return
     */
    @GetMapping("/getPortType")
    public RESTfulResult getPortType(){
        return success(rmsPortService.getPortType());
    }
}
